FlutterCustomToast class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
showToast({required BuildContext context, required String message, Color backgroundColor = const Color(0xFF002147), TextStyle textStyle = const TextStyle(color: Colors.white, fontWeight: FontWeight.w600), Duration duration = const Duration(seconds: 3), Duration animationDuration = const Duration(milliseconds: 500)})
→ void
-
Displays a custom toast message